# -*- coding: utf-8 -*-

import inventree.base


class Build(inventree.base.InventreeObject):
    """ Class representing the Build database model """

    URL = 'build'
